@@ -10,7 +10,9 @@ void config::parse_from_argv(int argc, char **argv)
 	desc.add_options()
 		("help,h", "some help")
 		("file,F", bpo::bool_switch(&file_flag)->default_value(false), "read data from file rather than raw disk")
-		("listen,l", bpo::value<std::string>(&listen_address), "gRPC service listen address and port, default is 127.0.0.1:50051");
+		("listen,l", bpo::value<std::string>(&listen_address), "gRPC service listen address and port, default is 127.0.0.1:50051")
+		("version,v", "show version")
+	;
 	// clang-format on
 
 	// clang-format off
@@ -26,6 +28,11 @@ void config::parse_from_argv(int argc, char **argv)
 		std::cout << desc << std::endl;
 		exit(0);
 	}
+
+	if (vmap.count("version")) {
+		std::cout << "ezio " << GIT_VERSION << std::endl;
+		exit(0);
+	}
 }
 
 } // namepsace ezio
